# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class RateLimitQuotasWriteRequest(BaseModel):
    """
    RateLimitQuotasWriteRequest
    """ # noqa: E501
    block_interval: Optional[StrictStr] = Field(default=None, description="If set, when a client reaches a rate limit threshold, the client will be prohibited from any further requests until after the 'block_interval' has elapsed.")
    inheritable: Optional[StrictBool] = Field(default=None, description="Whether all child namespaces can inherit this namespace quota.")
    interval: Optional[StrictStr] = Field(default=None, description="The duration to enforce rate limiting for (default '1s').")
    path: Optional[StrictStr] = Field(default=None, description="Path of the mount or namespace to apply the quota. A blank path configures a global quota. For example namespace1/ adds a quota to a full namespace, namespace1/auth/userpass adds a quota to userpass in namespace1.")
    rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The maximum number of requests in a given interval to be allowed by the quota rule. The 'rate' must be positive.")
    role: Optional[StrictStr] = Field(default=None, description="Login role to apply this quota to. Note that when set, path must be configured to a valid auth method with a concept of roles.")
    type: Optional[StrictStr] = Field(default=None, description="Type of the quota rule.")
    __properties: ClassVar[List[str]] = ["block_interval", "inheritable", "interval", "path", "rate", "role", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RateLimitQuotasWriteRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RateLimitQuotasWriteRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "block_interval": obj.get("block_interval"),
            "inheritable": obj.get("inheritable"),
            "interval": obj.get("interval"),
            "path": obj.get("path"),
            "rate": obj.get("rate"),
            "role": obj.get("role"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.kerberos_configure_request import KerberosConfigureRequest

class TestKerberosConfigureRequest(unittest.TestCase):
    """KerberosConfigureRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KerberosConfigureRequest:
        """Test KerberosConfigureRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KerberosConfigureRequest`
        """
        model = KerberosConfigureRequest()
        if include_optional:
            return KerberosConfigureRequest(
                add_group_aliases = True,
                keytab = '',
                remove_instance_name = True,
                service_account = ''
            )
        else:
            return KerberosConfigureRequest(
        )
        """

    def testKerberosConfigureRequest(self):
        """Test KerberosConfigureRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiIssuersGenerateRootRequest(BaseModel):
    """
    PkiIssuersGenerateRootRequest
    """ # noqa: E501
    alt_names: Optional[StrictStr] = Field(default=None, description="The requested Subject Alternative Names, if any, in a comma-delimited list. May contain both DNS names and email addresses.")
    common_name: Optional[StrictStr] = Field(default=None, description="The requested common name; if you want more than one, specify the alternative names in the alt_names map. If not specified when signing, the common name will be taken from the CSR; other names must still be specified in alt_names or ip_sans.")
    country: Optional[List[StrictStr]] = Field(default=None, description="If set, Country will be set to this value.")
    exclude_cn_from_sans: Optional[StrictBool] = Field(default=False, description="If true, the Common Name will not be included in DNS or Email Subject Alternate Names. Defaults to false (CN is included).")
    format: Optional[StrictStr] = Field(default='pem', description="Format for returned data. Can be \"pem\", \"der\", or \"pem_bundle\". If \"pem_bundle\", any private key and issuing cert will be appended to the certificate pem. If \"der\", the value will be base64 encoded. Defaults to \"pem\".")
    ip_sans: Optional[List[StrictStr]] = Field(default=None, description="The requested IP SANs, if any, in a comma-delimited list")
    issuer_name: Optional[StrictStr] = Field(default=None, description="Provide a name to the generated or existing issuer, the name must be unique across all issuers and not be the reserved value 'default'")
    key_bits: Optional[StrictInt] = Field(default=0, description="The number of bits to use. Allowed values are 0 (universal default); with rsa key_type: 2048 (default), 3072, or 4096; with ec key_type: 224, 256 (default), 384, or 521; ignored with ed25519.")
    key_name: Optional[StrictStr] = Field(default=None, description="Provide a name to the generated or existing key, the name must be unique across all keys and not be the reserved value 'default'")
    key_ref: Optional[StrictStr] = Field(default='default', description="Reference to a existing key; either \"default\" for the configured default key, an identifier or the name assigned to the key.")
    key_type: Optional[StrictStr] = Field(default='rsa', description="The type of key to use; defaults to RSA. \"rsa\" \"ec\" and \"ed25519\" are the only valid values.")
    locality: Optional[List[StrictStr]] = Field(default=None, description="If set, Locality will be set to this value.")
    managed_key_id: Optional[StrictStr] = Field(default=None, description="The name of the managed key to use when the exported type is kms. When kms type is the key type, this field or managed_key_name is required. Ignored for other types.")
    managed_key_name: Optional[StrictStr] = Field(default=None, description="The name of the managed key to use when the exported type is kms. When kms type is the key type, this field or managed_key_id is required. Ignored for other types.")
    max_path_length: Optional[StrictInt] = Field(default=-1, description="The maximum allowable path length")
    not_after: Optional[StrictStr] = Field(default=None, description="Set the not after field of the certificate with specified date value. The value format should be given in UTC format YYYY-MM-ddTHH:MM:SSZ")
    not_before_duration: Optional[StrictStr] = Field(default='30', description="The duration before now which the certificate needs to be backdated by.")
    organization: Optional[List[StrictStr]] = Field(default=None, description="If set, O (Organization) will be set to this value.")
    other_sans: Optional[List[StrictStr]] = Field(default=None, description="Requested other SANs, in an array with the format <oid>;UTF8:<utf8 string value> for each entry.")
    ou: Optional[List[StrictStr]] = Field(default=None, description="If set, OU (OrganizationalUnit) will be set to this value.")
    permitted_dns_domains: Optional[List[StrictStr]] = Field(default=None, description="Domains for which this certificate is allowed to sign or issue child certificates. If set, all DNS names (subject and alt) on child certs must be exact matches or subsets of the given domains (see https://tools.ietf.org/html/rfc5280#section-4.2.1.10).")
    postal_code: Optional[List[StrictStr]] = Field(default=None, description="If set, Postal Code will be set to this value.")
    private_key_format: Optional[StrictStr] = Field(default='der', description="Format for the returned private key. Generally the default will be controlled by the \"format\" parameter as either base64-encoded DER or PEM-encoded DER. However, this can be set to \"pkcs8\" to have the returned private key contain base64-encoded pkcs8 or PEM-encoded pkcs8 instead. Defaults to \"der\".")
    province: Optional[List[StrictStr]] = Field(default=None, description="If set, Province will be set to this value.")
    serial_number: Optional[StrictStr] = Field(default=None, description="The Subject's requested serial number, if any. See RFC 4519 Section 2.31 'serialNumber' for a description of this field. If you want more than one, specify alternative names in the alt_names map using OID 2.5.4.5. This has no impact on the final certificate's Serial Number field.")
    signature_bits: Optional[StrictInt] = Field(default=0, description="The number of bits to use in the signature algorithm; accepts 256 for SHA-2-256, 384 for SHA-2-384, and 512 for SHA-2-512. Defaults to 0 to automatically detect based on key length (SHA-2-256 for RSA keys, and matching the curve size for NIST P-Curves).")
    street_address: Optional[List[StrictStr]] = Field(default=None, description="If set, Street Address will be set to this value.")
    ttl: Optional[StrictStr] = Field(default=None, description="The requested Time To Live for the certificate; sets the expiration date. If not specified the role default, backend default, or system default TTL is used, in that order. Cannot be larger than the mount max TTL. Note: this only has an effect when generating a CA cert or signing a CA cert, not when generating a CSR for an intermediate CA.")
    uri_sans: Optional[List[StrictStr]] = Field(default=None, description="The requested URI SANs, if any, in a comma-delimited list.")
    use_pss: Optional[StrictBool] = Field(default=False, description="Whether or not to use PSS signatures when using a RSA key-type issuer. Defaults to false.")
    __properties: ClassVar[List[str]] = ["alt_names", "common_name", "country", "exclude_cn_from_sans", "format", "ip_sans", "issuer_name", "key_bits", "key_name", "key_ref", "key_type", "locality", "managed_key_id", "managed_key_name", "max_path_length", "not_after", "not_before_duration", "organization", "other_sans", "ou", "permitted_dns_domains", "postal_code", "private_key_format", "province", "serial_number", "signature_bits", "street_address", "ttl", "uri_sans", "use_pss"]

    @field_validator('format')
    def format_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['pem', 'der', 'pem_bundle']):
            raise ValueError("must be one of enum values ('pem', 'der', 'pem_bundle')")
        return value

    @field_validator('key_type')
    def key_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['rsa', 'ec', 'ed25519']):
            raise ValueError("must be one of enum values ('rsa', 'ec', 'ed25519')")
        return value

    @field_validator('private_key_format')
    def private_key_format_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['', 'der', 'pem', 'pkcs8']):
            raise ValueError("must be one of enum values ('', 'der', 'pem', 'pkcs8')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiIssuersGenerateRootRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiIssuersGenerateRootRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "alt_names": obj.get("alt_names"),
            "common_name": obj.get("common_name"),
            "country": obj.get("country"),
            "exclude_cn_from_sans": obj.get("exclude_cn_from_sans") if obj.get("exclude_cn_from_sans") is not None else False,
            "format": obj.get("format") if obj.get("format") is not None else 'pem',
            "ip_sans": obj.get("ip_sans"),
            "issuer_name": obj.get("issuer_name"),
            "key_bits": obj.get("key_bits") if obj.get("key_bits") is not None else 0,
            "key_name": obj.get("key_name"),
            "key_ref": obj.get("key_ref") if obj.get("key_ref") is not None else 'default',
            "key_type": obj.get("key_type") if obj.get("key_type") is not None else 'rsa',
            "locality": obj.get("locality"),
            "managed_key_id": obj.get("managed_key_id"),
            "managed_key_name": obj.get("managed_key_name"),
            "max_path_length": obj.get("max_path_length") if obj.get("max_path_length") is not None else -1,
            "not_after": obj.get("not_after"),
            "not_before_duration": obj.get("not_before_duration") if obj.get("not_before_duration") is not None else '30',
            "organization": obj.get("organization"),
            "other_sans": obj.get("other_sans"),
            "ou": obj.get("ou"),
            "permitted_dns_domains": obj.get("permitted_dns_domains"),
            "postal_code": obj.get("postal_code"),
            "private_key_format": obj.get("private_key_format") if obj.get("private_key_format") is not None else 'der',
            "province": obj.get("province"),
            "serial_number": obj.get("serial_number"),
            "signature_bits": obj.get("signature_bits") if obj.get("signature_bits") is not None else 0,
            "street_address": obj.get("street_address"),
            "ttl": obj.get("ttl"),
            "uri_sans": obj.get("uri_sans"),
            "use_pss": obj.get("use_pss") if obj.get("use_pss") is not None else False
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.pki_tidy_request import PkiTidyRequest

class TestPkiTidyRequest(unittest.TestCase):
    """PkiTidyRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PkiTidyRequest:
        """Test PkiTidyRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PkiTidyRequest`
        """
        model = PkiTidyRequest()
        if include_optional:
            return PkiTidyRequest(
                acme_account_safety_buffer = '2592000',
                issuer_safety_buffer = '31536000',
                pause_duration = '0s',
                revocation_queue_safety_buffer = '172800',
                safety_buffer = '259200',
                tidy_acme = True,
                tidy_cert_store = True,
                tidy_cross_cluster_revoked_certs = True,
                tidy_expired_issuers = True,
                tidy_move_legacy_ca_bundle = True,
                tidy_revocation_list = True,
                tidy_revocation_queue = True,
                tidy_revoked_cert_issuer_associations = True,
                tidy_revoked_certs = True
            )
        else:
            return PkiTidyRequest(
        )
        """

    def testPkiTidyRequest(self):
        """Test PkiTidyRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.api.identity_api import IdentityApi


class TestIdentityApi(unittest.TestCase):
    """IdentityApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentityApi()

    def tearDown(self) -> None:
        pass

    def test_alias_create(self) -> None:
        """Test case for alias_create

        Create a new alias.
        """
        pass

    def test_alias_delete_by_id(self) -> None:
        """Test case for alias_delete_by_id

        """
        pass

    def test_alias_list_by_id(self) -> None:
        """Test case for alias_list_by_id

        List all the alias IDs.
        """
        pass

    def test_alias_read_by_id(self) -> None:
        """Test case for alias_read_by_id

        """
        pass

    def test_alias_update_by_id(self) -> None:
        """Test case for alias_update_by_id

        """
        pass

    def test_entity_batch_delete(self) -> None:
        """Test case for entity_batch_delete

        Delete all of the entities provided
        """
        pass

    def test_entity_create(self) -> None:
        """Test case for entity_create

        Create a new entity
        """
        pass

    def test_entity_create_alias(self) -> None:
        """Test case for entity_create_alias

        Create a new alias.
        """
        pass

    def test_entity_delete_alias_by_id(self) -> None:
        """Test case for entity_delete_alias_by_id

        """
        pass

    def test_entity_delete_by_id(self) -> None:
        """Test case for entity_delete_by_id

        """
        pass

    def test_entity_delete_by_name(self) -> None:
        """Test case for entity_delete_by_name

        """
        pass

    def test_entity_list_aliases_by_id(self) -> None:
        """Test case for entity_list_aliases_by_id

        List all the alias IDs.
        """
        pass

    def test_entity_list_by_id(self) -> None:
        """Test case for entity_list_by_id

        List all the entity IDs
        """
        pass

    def test_entity_list_by_name(self) -> None:
        """Test case for entity_list_by_name

        List all the entity names
        """
        pass

    def test_entity_look_up(self) -> None:
        """Test case for entity_look_up

        Query entities based on various properties.
        """
        pass

    def test_entity_merge(self) -> None:
        """Test case for entity_merge

        Merge two or more entities together
        """
        pass

    def test_entity_read_alias_by_id(self) -> None:
        """Test case for entity_read_alias_by_id

        """
        pass

    def test_entity_read_by_id(self) -> None:
        """Test case for entity_read_by_id

        """
        pass

    def test_entity_read_by_name(self) -> None:
        """Test case for entity_read_by_name

        """
        pass

    def test_entity_update_alias_by_id(self) -> None:
        """Test case for entity_update_alias_by_id

        """
        pass

    def test_entity_update_by_id(self) -> None:
        """Test case for entity_update_by_id

        """
        pass

    def test_entity_update_by_name(self) -> None:
        """Test case for entity_update_by_name

        """
        pass

    def test_group_create(self) -> None:
        """Test case for group_create

        """
        pass

    def test_group_create_alias(self) -> None:
        """Test case for group_create_alias

        Creates a new group alias, or updates an existing one.
        """
        pass

    def test_group_delete_alias_by_id(self) -> None:
        """Test case for group_delete_alias_by_id

        """
        pass

    def test_group_delete_by_id(self) -> None:
        """Test case for group_delete_by_id

        """
        pass

    def test_group_delete_by_name(self) -> None:
        """Test case for group_delete_by_name

        """
        pass

    def test_group_list_aliases_by_id(self) -> None:
        """Test case for group_list_aliases_by_id

        List all the group alias IDs.
        """
        pass

    def test_group_list_by_id(self) -> None:
        """Test case for group_list_by_id

        List all the group IDs.
        """
        pass

    def test_group_list_by_name(self) -> None:
        """Test case for group_list_by_name

        """
        pass

    def test_group_look_up(self) -> None:
        """Test case for group_look_up

        Query groups based on various properties.
        """
        pass

    def test_group_read_alias_by_id(self) -> None:
        """Test case for group_read_alias_by_id

        """
        pass

    def test_group_read_by_id(self) -> None:
        """Test case for group_read_by_id

        """
        pass

    def test_group_read_by_name(self) -> None:
        """Test case for group_read_by_name

        """
        pass

    def test_group_update_alias_by_id(self) -> None:
        """Test case for group_update_alias_by_id

        """
        pass

    def test_group_update_by_id(self) -> None:
        """Test case for group_update_by_id

        """
        pass

    def test_group_update_by_name(self) -> None:
        """Test case for group_update_by_name

        """
        pass

    def test_mfa_admin_destroy_totp_secret(self) -> None:
        """Test case for mfa_admin_destroy_totp_secret

        Destroys a TOTP secret for the given MFA method ID on the given entity
        """
        pass

    def test_mfa_admin_generate_totp_secret(self) -> None:
        """Test case for mfa_admin_generate_totp_secret

        Update or create TOTP secret for the given method ID on the given entity.
        """
        pass

    def test_mfa_create_duo_method(self) -> None:
        """Test case for mfa_create_duo_method

        Create the given MFA method
        """
        pass

    def test_mfa_create_okta_method(self) -> None:
        """Test case for mfa_create_okta_method

        Create the given MFA method
        """
        pass

    def test_mfa_create_ping_id_method(self) -> None:
        """Test case for mfa_create_ping_id_method

        Create the given MFA method
        """
        pass

    def test_mfa_create_totp_method(self) -> None:
        """Test case for mfa_create_totp_method

        Create the given MFA method
        """
        pass

    def test_mfa_delete_duo_method(self) -> None:
        """Test case for mfa_delete_duo_method

        Delete the given MFA method
        """
        pass

    def test_mfa_delete_login_enforcement(self) -> None:
        """Test case for mfa_delete_login_enforcement

        Delete a login enforcement
        """
        pass

    def test_mfa_delete_okta_method(self) -> None:
        """Test case for mfa_delete_okta_method

        Delete the given MFA method
        """
        pass

    def test_mfa_delete_ping_id_method(self) -> None:
        """Test case for mfa_delete_ping_id_method

        Delete the given MFA method
        """
        pass

    def test_mfa_delete_totp_method(self) -> None:
        """Test case for mfa_delete_totp_method

        Delete the given MFA method
        """
        pass

    def test_mfa_generate_totp_secret(self) -> None:
        """Test case for mfa_generate_totp_secret

        Update or create TOTP secret for the given method ID on the given entity.
        """
        pass

    def test_mfa_list_duo_methods(self) -> None:
        """Test case for mfa_list_duo_methods

        List MFA method configurations for the given MFA method
        """
        pass

    def test_mfa_list_login_enforcements(self) -> None:
        """Test case for mfa_list_login_enforcements

        List login enforcements
        """
        pass

    def test_mfa_list_methods(self) -> None:
        """Test case for mfa_list_methods

        List MFA method configurations for all MFA methods
        """
        pass

    def test_mfa_list_okta_methods(self) -> None:
        """Test case for mfa_list_okta_methods

        List MFA method configurations for the given MFA method
        """
        pass

    def test_mfa_list_ping_id_methods(self) -> None:
        """Test case for mfa_list_ping_id_methods

        List MFA method configurations for the given MFA method
        """
        pass

    def test_mfa_list_totp_methods(self) -> None:
        """Test case for mfa_list_totp_methods

        List MFA method configurations for the given MFA method
        """
        pass

    def test_mfa_read_duo_method(self) -> None:
        """Test case for mfa_read_duo_method

        Read the current configuration for the given MFA method
        """
        pass

    def test_mfa_read_login_enforcement(self) -> None:
        """Test case for mfa_read_login_enforcement

        Read the current login enforcement
        """
        pass

    def test_mfa_read_method(self) -> None:
        """Test case for mfa_read_method

        Read the current configuration for the given ID regardless of the MFA method type
        """
        pass

    def test_mfa_read_okta_method(self) -> None:
        """Test case for mfa_read_okta_method

        Read the current configuration for the given MFA method
        """
        pass

    def test_mfa_read_ping_id_method(self) -> None:
        """Test case for mfa_read_ping_id_method

        Read the current configuration for the given MFA method
        """
        pass

    def test_mfa_read_totp_method(self) -> None:
        """Test case for mfa_read_totp_method

        Read the current configuration for the given MFA method
        """
        pass

    def test_mfa_update_duo_method(self) -> None:
        """Test case for mfa_update_duo_method

        Update the configuration for the given MFA method
        """
        pass

    def test_mfa_update_okta_method(self) -> None:
        """Test case for mfa_update_okta_method

        Update the configuration for the given MFA method
        """
        pass

    def test_mfa_update_ping_id_method(self) -> None:
        """Test case for mfa_update_ping_id_method

        Update the configuration for the given MFA method
        """
        pass

    def test_mfa_update_totp_method(self) -> None:
        """Test case for mfa_update_totp_method

        Update the configuration for the given MFA method
        """
        pass

    def test_mfa_write_login_enforcement(self) -> None:
        """Test case for mfa_write_login_enforcement

        Create or update a login enforcement
        """
        pass

    def test_oidc_configure(self) -> None:
        """Test case for oidc_configure

        """
        pass

    def test_oidc_delete_assignment(self) -> None:
        """Test case for oidc_delete_assignment

        """
        pass

    def test_oidc_delete_client(self) -> None:
        """Test case for oidc_delete_client

        """
        pass

    def test_oidc_delete_key(self) -> None:
        """Test case for oidc_delete_key

        CRUD operations for OIDC keys.
        """
        pass

    def test_oidc_delete_provider(self) -> None:
        """Test case for oidc_delete_provider

        """
        pass

    def test_oidc_delete_role(self) -> None:
        """Test case for oidc_delete_role

        CRUD operations on OIDC Roles
        """
        pass

    def test_oidc_delete_scope(self) -> None:
        """Test case for oidc_delete_scope

        """
        pass

    def test_oidc_generate_token(self) -> None:
        """Test case for oidc_generate_token

        Generate an OIDC token
        """
        pass

    def test_oidc_introspect(self) -> None:
        """Test case for oidc_introspect

        Verify the authenticity of an OIDC token
        """
        pass

    def test_oidc_list_assignments(self) -> None:
        """Test case for oidc_list_assignments

        """
        pass

    def test_oidc_list_clients(self) -> None:
        """Test case for oidc_list_clients

        """
        pass

    def test_oidc_list_keys(self) -> None:
        """Test case for oidc_list_keys

        List OIDC keys
        """
        pass

    def test_oidc_list_providers(self) -> None:
        """Test case for oidc_list_providers

        """
        pass

    def test_oidc_list_roles(self) -> None:
        """Test case for oidc_list_roles

        List configured OIDC roles
        """
        pass

    def test_oidc_list_scopes(self) -> None:
        """Test case for oidc_list_scopes

        """
        pass

    def test_oidc_provider_authorize(self) -> None:
        """Test case for oidc_provider_authorize

        """
        pass

    def test_oidc_provider_authorize_with_parameters(self) -> None:
        """Test case for oidc_provider_authorize_with_parameters

        """
        pass

    def test_oidc_provider_token(self) -> None:
        """Test case for oidc_provider_token

        """
        pass

    def test_oidc_provider_user_info(self) -> None:
        """Test case for oidc_provider_user_info

        """
        pass

    def test_oidc_provider_user_info2(self) -> None:
        """Test case for oidc_provider_user_info2

        """
        pass

    def test_oidc_read_assignment(self) -> None:
        """Test case for oidc_read_assignment

        """
        pass

    def test_oidc_read_client(self) -> None:
        """Test case for oidc_read_client

        """
        pass

    def test_oidc_read_configuration(self) -> None:
        """Test case for oidc_read_configuration

        """
        pass

    def test_oidc_read_key(self) -> None:
        """Test case for oidc_read_key

        CRUD operations for OIDC keys.
        """
        pass

    def test_oidc_read_open_id_configuration(self) -> None:
        """Test case for oidc_read_open_id_configuration

        Query OIDC configurations
        """
        pass

    def test_oidc_read_provider(self) -> None:
        """Test case for oidc_read_provider

        """
        pass

    def test_oidc_read_provider_open_id_configuration(self) -> None:
        """Test case for oidc_read_provider_open_id_configuration

        """
        pass

    def test_oidc_read_provider_public_keys(self) -> None:
        """Test case for oidc_read_provider_public_keys

        """
        pass

    def test_oidc_read_public_keys(self) -> None:
        """Test case for oidc_read_public_keys

        Retrieve public keys
        """
        pass

    def test_oidc_read_role(self) -> None:
        """Test case for oidc_read_role

        CRUD operations on OIDC Roles
        """
        pass

    def test_oidc_read_scope(self) -> None:
        """Test case for oidc_read_scope

        """
        pass

    def test_oidc_rotate_key(self) -> None:
        """Test case for oidc_rotate_key

        Rotate a named OIDC key.
        """
        pass

    def test_oidc_write_assignment(self) -> None:
        """Test case for oidc_write_assignment

        """
        pass

    def test_oidc_write_client(self) -> None:
        """Test case for oidc_write_client

        """
        pass

    def test_oidc_write_key(self) -> None:
        """Test case for oidc_write_key

        CRUD operations for OIDC keys.
        """
        pass

    def test_oidc_write_provider(self) -> None:
        """Test case for oidc_write_provider

        """
        pass

    def test_oidc_write_role(self) -> None:
        """Test case for oidc_write_role

        CRUD operations on OIDC Roles
        """
        pass

    def test_oidc_write_scope(self) -> None:
        """Test case for oidc_write_scope

        """
        pass

    def test_persona_create(self) -> None:
        """Test case for persona_create

        Create a new alias.
        """
        pass

    def test_persona_delete_by_id(self) -> None:
        """Test case for persona_delete_by_id

        """
        pass

    def test_persona_list_by_id(self) -> None:
        """Test case for persona_list_by_id

        List all the alias IDs.
        """
        pass

    def test_persona_read_by_id(self) -> None:
        """Test case for persona_read_by_id

        """
        pass

    def test_persona_update_by_id(self) -> None:
        """Test case for persona_update_by_id

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AwsConfigureIdentityIntegrationRequest(BaseModel):
    """
    AwsConfigureIdentityIntegrationRequest
    """ # noqa: E501
    ec2_alias: Optional[StrictStr] = Field(default='instance_id', description="Configure how the AWS auth method generates entity alias when using EC2 auth. Valid values are \"role_id\", \"instance_id\", and \"image_id\". Defaults to \"role_id\".")
    ec2_metadata: Optional[List[StrictStr]] = Field(default=None, description="The metadata to include on the aliases and audit logs generated by this plugin. When set to 'default', includes: account_id, auth_type. These fields are available to add: ami_id, instance_id, region. Not editing this field means the 'default' fields are included. Explicitly setting this field to empty overrides the 'default' and means no metadata will be included. If not using 'default', explicit fields must be sent like: 'field1,field2'.")
    iam_alias: Optional[StrictStr] = Field(default='unique_id', description="Configure how the AWS auth method generates entity aliases when using IAM auth. Valid values are \"role_id\", \"unique_id\", and \"full_arn\". Defaults to \"role_id\".")
    iam_metadata: Optional[List[StrictStr]] = Field(default=None, description="The metadata to include on the aliases and audit logs generated by this plugin. When set to 'default', includes: account_id, auth_type. These fields are available to add: canonical_arn, client_arn, client_user_id, inferred_aws_region, inferred_entity_id, inferred_entity_type. Not editing this field means the 'default' fields are included. Explicitly setting this field to empty overrides the 'default' and means no metadata will be included. If not using 'default', explicit fields must be sent like: 'field1,field2'.")
    __properties: ClassVar[List[str]] = ["ec2_alias", "ec2_metadata", "iam_alias", "iam_metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AwsConfigureIdentityIntegrationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AwsConfigureIdentityIntegrationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ec2_alias": obj.get("ec2_alias") if obj.get("ec2_alias") is not None else 'instance_id',
            "ec2_metadata": obj.get("ec2_metadata"),
            "iam_alias": obj.get("iam_alias") if obj.get("iam_alias") is not None else 'unique_id',
            "iam_metadata": obj.get("iam_metadata")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.pki_root_sign_intermediate_request import PkiRootSignIntermediateRequest

class TestPkiRootSignIntermediateRequest(unittest.TestCase):
    """PkiRootSignIntermediateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PkiRootSignIntermediateRequest:
        """Test PkiRootSignIntermediateRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PkiRootSignIntermediateRequest`
        """
        model = PkiRootSignIntermediateRequest()
        if include_optional:
            return PkiRootSignIntermediateRequest(
                alt_names = '',
                common_name = '',
                country = [
                    ''
                    ],
                csr = '',
                exclude_cn_from_sans = True,
                format = 'pem',
                ip_sans = [
                    ''
                    ],
                issuer_name = '',
                issuer_ref = 'default',
                locality = [
                    ''
                    ],
                max_path_length = 56,
                not_after = '',
                not_before_duration = '30',
                organization = [
                    ''
                    ],
                other_sans = [
                    ''
                    ],
                ou = [
                    ''
                    ],
                permitted_dns_domains = [
                    ''
                    ],
                postal_code = [
                    ''
                    ],
                private_key_format = 'der',
                province = [
                    ''
                    ],
                serial_number = '',
                signature_bits = 56,
                skid = '',
                street_address = [
                    ''
                    ],
                ttl = '',
                uri_sans = [
                    ''
                    ],
                use_csr_values = True,
                use_pss = True
            )
        else:
            return PkiRootSignIntermediateRequest(
        )
        """

    def testPkiRootSignIntermediateRequest(self):
        """Test PkiRootSignIntermediateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiGenerateInternalKeyRequest(BaseModel):
    """
    PkiGenerateInternalKeyRequest
    """ # noqa: E501
    key_bits: Optional[StrictInt] = Field(default=0, description="The number of bits to use. Allowed values are 0 (universal default); with rsa key_type: 2048 (default), 3072, or 4096; with ec key_type: 224, 256 (default), 384, or 521; ignored with ed25519.")
    key_name: Optional[StrictStr] = Field(default=None, description="Optional name to be used for this key")
    key_type: Optional[StrictStr] = Field(default='rsa', description="The type of key to use; defaults to RSA. \"rsa\" \"ec\" and \"ed25519\" are the only valid values.")
    managed_key_id: Optional[StrictStr] = Field(default=None, description="The name of the managed key to use when the exported type is kms. When kms type is the key type, this field or managed_key_name is required. Ignored for other types.")
    managed_key_name: Optional[StrictStr] = Field(default=None, description="The name of the managed key to use when the exported type is kms. When kms type is the key type, this field or managed_key_id is required. Ignored for other types.")
    __properties: ClassVar[List[str]] = ["key_bits", "key_name", "key_type", "managed_key_id", "managed_key_name"]

    @field_validator('key_type')
    def key_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['rsa', 'ec', 'ed25519']):
            raise ValueError("must be one of enum values ('rsa', 'ec', 'ed25519')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiGenerateInternalKeyRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiGenerateInternalKeyRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "key_bits": obj.get("key_bits") if obj.get("key_bits") is not None else 0,
            "key_name": obj.get("key_name"),
            "key_type": obj.get("key_type") if obj.get("key_type") is not None else 'rsa',
            "managed_key_id": obj.get("managed_key_id"),
            "managed_key_name": obj.get("managed_key_name")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.userpass_write_user_request import UserpassWriteUserRequest

class TestUserpassWriteUserRequest(unittest.TestCase):
    """UserpassWriteUserRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserpassWriteUserRequest:
        """Test UserpassWriteUserRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserpassWriteUserRequest`
        """
        model = UserpassWriteUserRequest()
        if include_optional:
            return UserpassWriteUserRequest(
                bound_cidrs = [
                    ''
                    ],
                max_ttl = '',
                password = '',
                policies = [
                    ''
                    ],
                token_bound_cidrs = [
                    ''
                    ],
                token_explicit_max_ttl = '',
                token_max_ttl = '',
                token_no_default_policy = True,
                token_num_uses = 56,
                token_period = '',
                token_policies = [
                    ''
                    ],
                token_ttl = '',
                token_type = 'default-service',
                ttl = ''
            )
        else:
            return UserpassWriteUserRequest(
        )
        """

    def testUserpassWriteUserRequest(self):
        """Test UserpassWriteUserRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.pki_generate_root_request import PkiGenerateRootRequest

class TestPkiGenerateRootRequest(unittest.TestCase):
    """PkiGenerateRootRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PkiGenerateRootRequest:
        """Test PkiGenerateRootRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PkiGenerateRootRequest`
        """
        model = PkiGenerateRootRequest()
        if include_optional:
            return PkiGenerateRootRequest(
                alt_names = '',
                common_name = '',
                country = [
                    ''
                    ],
                exclude_cn_from_sans = True,
                format = 'pem',
                ip_sans = [
                    ''
                    ],
                issuer_name = '',
                key_bits = 56,
                key_name = '',
                key_ref = 'default',
                key_type = 'rsa',
                locality = [
                    ''
                    ],
                managed_key_id = '',
                managed_key_name = '',
                max_path_length = 56,
                not_after = '',
                not_before_duration = '30',
                organization = [
                    ''
                    ],
                other_sans = [
                    ''
                    ],
                ou = [
                    ''
                    ],
                permitted_dns_domains = [
                    ''
                    ],
                postal_code = [
                    ''
                    ],
                private_key_format = 'der',
                province = [
                    ''
                    ],
                serial_number = '',
                signature_bits = 56,
                street_address = [
                    ''
                    ],
                ttl = '',
                uri_sans = [
                    ''
                    ],
                use_pss = True
            )
        else:
            return PkiGenerateRootRequest(
        )
        """

    def testPkiGenerateRootRequest(self):
        """Test PkiGenerateRootRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CloudFoundryConfigureRequest(BaseModel):
    """
    CloudFoundryConfigureRequest
    """ # noqa: E501
    cf_api_addr: Optional[StrictStr] = Field(default=None, description="CF’s API address.")
    cf_api_mutual_tls_certificate: Optional[StrictStr] = Field(default=None, description="The PEM-format certificates that are presented for mutual TLS with the CloudFoundry API. If not set, mutual TLS is not used")
    cf_api_mutual_tls_key: Optional[StrictStr] = Field(default=None, description="The PEM-format private key that are used for mutual TLS with the CloudFoundry API. If not set, mutual TLS is not used")
    cf_api_trusted_certificates: Optional[List[StrictStr]] = Field(default=None, description="The PEM-format CA certificates that are acceptable for the CF API to present.")
    cf_client_id: Optional[StrictStr] = Field(default=None, description="The client id for CF’s API.")
    cf_client_secret: Optional[StrictStr] = Field(default=None, description="The client secret for CF’s API.")
    cf_password: Optional[StrictStr] = Field(default=None, description="The password for CF’s API.")
    cf_username: Optional[StrictStr] = Field(default=None, description="The username for CF’s API.")
    identity_ca_certificates: Optional[List[StrictStr]] = Field(default=None, description="The PEM-format CA certificates that are required to have issued the instance certificates presented for logging in.")
    login_max_seconds_not_after: Optional[StrictInt] = Field(default=60, description="Duration in seconds for the maximum acceptable length in the future a \"signing_time\" can be. Useful for clock drift. Set low to reduce the opportunity for replay attacks.")
    login_max_seconds_not_before: Optional[StrictStr] = Field(default='300', description="Duration in seconds for the maximum acceptable age of a \"signing_time\". Useful for clock drift. Set low to reduce the opportunity for replay attacks.")
    pcf_api_addr: Optional[StrictStr] = Field(default=None, description="Deprecated. Please use \"cf_api_addr\".")
    pcf_api_trusted_certificates: Optional[List[StrictStr]] = Field(default=None, description="Deprecated. Please use \"cf_api_trusted_certificates\".")
    pcf_password: Optional[StrictStr] = Field(default=None, description="Deprecated. Please use \"cf_password\".")
    pcf_username: Optional[StrictStr] = Field(default=None, description="Deprecated. Please use \"cf_username\".")
    __properties: ClassVar[List[str]] = ["cf_api_addr", "cf_api_mutual_tls_certificate", "cf_api_mutual_tls_key", "cf_api_trusted_certificates", "cf_client_id", "cf_client_secret", "cf_password", "cf_username", "identity_ca_certificates", "login_max_seconds_not_after", "login_max_seconds_not_before", "pcf_api_addr", "pcf_api_trusted_certificates", "pcf_password", "pcf_username"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CloudFoundryConfigureRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CloudFoundryConfigureRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cf_api_addr": obj.get("cf_api_addr"),
            "cf_api_mutual_tls_certificate": obj.get("cf_api_mutual_tls_certificate"),
            "cf_api_mutual_tls_key": obj.get("cf_api_mutual_tls_key"),
            "cf_api_trusted_certificates": obj.get("cf_api_trusted_certificates"),
            "cf_client_id": obj.get("cf_client_id"),
            "cf_client_secret": obj.get("cf_client_secret"),
            "cf_password": obj.get("cf_password"),
            "cf_username": obj.get("cf_username"),
            "identity_ca_certificates": obj.get("identity_ca_certificates"),
            "login_max_seconds_not_after": obj.get("login_max_seconds_not_after") if obj.get("login_max_seconds_not_after") is not None else 60,
            "login_max_seconds_not_before": obj.get("login_max_seconds_not_before") if obj.get("login_max_seconds_not_before") is not None else '300',
            "pcf_api_addr": obj.get("pcf_api_addr"),
            "pcf_api_trusted_certificates": obj.get("pcf_api_trusted_certificates"),
            "pcf_password": obj.get("pcf_password"),
            "pcf_username": obj.get("pcf_username")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.token_write_role_request import TokenWriteRoleRequest

class TestTokenWriteRoleRequest(unittest.TestCase):
    """TokenWriteRoleRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TokenWriteRoleRequest:
        """Test TokenWriteRoleRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TokenWriteRoleRequest`
        """
        model = TokenWriteRoleRequest()
        if include_optional:
            return TokenWriteRoleRequest(
                allowed_entity_aliases = [
                    ''
                    ],
                allowed_policies = [
                    ''
                    ],
                allowed_policies_glob = [
                    ''
                    ],
                bound_cidrs = [
                    ''
                    ],
                disallowed_policies = [
                    ''
                    ],
                disallowed_policies_glob = [
                    ''
                    ],
                explicit_max_ttl = '',
                orphan = True,
                path_suffix = '',
                period = '',
                renewable = True,
                token_bound_cidrs = [
                    ''
                    ],
                token_explicit_max_ttl = '',
                token_no_default_policy = True,
                token_num_uses = 56,
                token_period = '',
                token_type = 'default-service'
            )
        else:
            return TokenWriteRoleRequest(
        )
        """

    def testTokenWriteRoleRequest(self):
        """Test TokenWriteRoleRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AwsWriteRoleRequest(BaseModel):
    """
    AwsWriteRoleRequest
    """ # noqa: E501
    arn: Optional[StrictStr] = Field(default=None, description="Use role_arns or policy_arns instead.")
    credential_type: Optional[StrictStr] = Field(default=None, description="Type of credential to retrieve. Must be one of assumed_role, iam_user, or federation_token")
    default_sts_ttl: Optional[StrictStr] = Field(default=None, description="Default TTL for assumed_role and federation_token credential types when no TTL is explicitly requested with the credentials")
    iam_groups: Optional[List[StrictStr]] = Field(default=None, description="Names of IAM groups that generated IAM users will be added to. For a credential type of assumed_role or federation_token, the policies sent to the corresponding AWS call (sts:AssumeRole or sts:GetFederation) will be the policies from each group in iam_groups combined with the policy_document and policy_arns parameters.")
    iam_tags: Optional[Dict[str, Any]] = Field(default=None, description="IAM tags to be set for any users created by this role. These must be presented as Key-Value pairs. This can be represented as a map or a list of equal sign delimited key pairs.")
    max_sts_ttl: Optional[StrictStr] = Field(default=None, description="Max allowed TTL for assumed_role and federation_token credential types")
    permissions_boundary_arn: Optional[StrictStr] = Field(default=None, description="ARN of an IAM policy to attach as a permissions boundary on IAM user credentials; only valid when credential_type isiam_user")
    policy: Optional[StrictStr] = Field(default=None, description="Use policy_document instead.")
    policy_arns: Optional[List[StrictStr]] = Field(default=None, description="ARNs of AWS policies. Behavior varies by credential_type. When credential_type is iam_user, then it will attach the specified policies to the generated IAM user. When credential_type is assumed_role or federation_token, the policies will be passed as the PolicyArns parameter, acting as a filter on permissions available.")
    policy_document: Optional[StrictStr] = Field(default=None, description="JSON-encoded IAM policy document. Behavior varies by credential_type. When credential_type is iam_user, then it will attach the contents of the policy_document to the IAM user generated. When credential_type is assumed_role or federation_token, this will be passed in as the Policy parameter to the AssumeRole or GetFederationToken API call, acting as a filter on permissions available.")
    role_arns: Optional[List[StrictStr]] = Field(default=None, description="ARNs of AWS roles allowed to be assumed. Only valid when credential_type is assumed_role")
    user_path: Optional[StrictStr] = Field(default='/', description="Path for IAM User. Only valid when credential_type is iam_user")
    __properties: ClassVar[List[str]] = ["arn", "credential_type", "default_sts_ttl", "iam_groups", "iam_tags", "max_sts_ttl", "permissions_boundary_arn", "policy", "policy_arns", "policy_document", "role_arns", "user_path"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AwsWriteRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AwsWriteRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "arn": obj.get("arn"),
            "credential_type": obj.get("credential_type"),
            "default_sts_ttl": obj.get("default_sts_ttl"),
            "iam_groups": obj.get("iam_groups"),
            "iam_tags": obj.get("iam_tags"),
            "max_sts_ttl": obj.get("max_sts_ttl"),
            "permissions_boundary_arn": obj.get("permissions_boundary_arn"),
            "policy": obj.get("policy"),
            "policy_arns": obj.get("policy_arns"),
            "policy_document": obj.get("policy_document"),
            "role_arns": obj.get("role_arns"),
            "user_path": obj.get("user_path") if obj.get("user_path") is not None else '/'
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.api.auth_api import AuthApi


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthApi()

    def tearDown(self) -> None:
        pass

    def test_ali_cloud_delete_auth_role(self) -> None:
        """Test case for ali_cloud_delete_auth_role

        Create a role and associate policies to it.
        """
        pass

    def test_ali_cloud_list_auth_roles(self) -> None:
        """Test case for ali_cloud_list_auth_roles

        Lists all the roles that are registered with Vault.
        """
        pass

    def test_ali_cloud_list_auth_roles2(self) -> None:
        """Test case for ali_cloud_list_auth_roles2

        Lists all the roles that are registered with Vault.
        """
        pass

    def test_ali_cloud_login(self) -> None:
        """Test case for ali_cloud_login

        Authenticates an RAM entity with Vault.
        """
        pass

    def test_ali_cloud_read_auth_role(self) -> None:
        """Test case for ali_cloud_read_auth_role

        Create a role and associate policies to it.
        """
        pass

    def test_ali_cloud_write_auth_role(self) -> None:
        """Test case for ali_cloud_write_auth_role

        Create a role and associate policies to it.
        """
        pass

    def test_app_role_delete_bind_secret_id(self) -> None:
        """Test case for app_role_delete_bind_secret_id

        """
        pass

    def test_app_role_delete_bound_cidr_list(self) -> None:
        """Test case for app_role_delete_bound_cidr_list

        """
        pass

    def test_app_role_delete_period(self) -> None:
        """Test case for app_role_delete_period

        """
        pass

    def test_app_role_delete_policies(self) -> None:
        """Test case for app_role_delete_policies

        """
        pass

    def test_app_role_delete_role(self) -> None:
        """Test case for app_role_delete_role

        """
        pass

    def test_app_role_delete_secret_id_bound_cidrs(self) -> None:
        """Test case for app_role_delete_secret_id_bound_cidrs

        """
        pass

    def test_app_role_delete_secret_id_num_uses(self) -> None:
        """Test case for app_role_delete_secret_id_num_uses

        """
        pass

    def test_app_role_delete_secret_id_ttl(self) -> None:
        """Test case for app_role_delete_secret_id_ttl

        """
        pass

    def test_app_role_delete_token_bound_cidrs(self) -> None:
        """Test case for app_role_delete_token_bound_cidrs

        """
        pass

    def test_app_role_delete_token_max_ttl(self) -> None:
        """Test case for app_role_delete_token_max_ttl

        """
        pass

    def test_app_role_delete_token_num_uses(self) -> None:
        """Test case for app_role_delete_token_num_uses

        """
        pass

    def test_app_role_delete_token_ttl(self) -> None:
        """Test case for app_role_delete_token_ttl

        """
        pass

    def test_app_role_destroy_secret_id(self) -> None:
        """Test case for app_role_destroy_secret_id

        """
        pass

    def test_app_role_destroy_secret_id2(self) -> None:
        """Test case for app_role_destroy_secret_id2

        """
        pass

    def test_app_role_destroy_secret_id_by_accessor(self) -> None:
        """Test case for app_role_destroy_secret_id_by_accessor

        """
        pass

    def test_app_role_destroy_secret_id_by_accessor2(self) -> None:
        """Test case for app_role_destroy_secret_id_by_accessor2

        """
        pass

    def test_app_role_list_roles(self) -> None:
        """Test case for app_role_list_roles

        """
        pass

    def test_app_role_list_secret_ids(self) -> None:
        """Test case for app_role_list_secret_ids

        """
        pass

    def test_app_role_login(self) -> None:
        """Test case for app_role_login

        """
        pass

    def test_app_role_look_up_secret_id(self) -> None:
        """Test case for app_role_look_up_secret_id

        """
        pass

    def test_app_role_look_up_secret_id_by_accessor(self) -> None:
        """Test case for app_role_look_up_secret_id_by_accessor

        """
        pass

    def test_app_role_read_bind_secret_id(self) -> None:
        """Test case for app_role_read_bind_secret_id

        """
        pass

    def test_app_role_read_bound_cidr_list(self) -> None:
        """Test case for app_role_read_bound_cidr_list

        """
        pass

    def test_app_role_read_local_secret_ids(self) -> None:
        """Test case for app_role_read_local_secret_ids

        """
        pass

    def test_app_role_read_period(self) -> None:
        """Test case for app_role_read_period

        """
        pass

    def test_app_role_read_policies(self) -> None:
        """Test case for app_role_read_policies

        """
        pass

    def test_app_role_read_role(self) -> None:
        """Test case for app_role_read_role

        """
        pass

    def test_app_role_read_role_id(self) -> None:
        """Test case for app_role_read_role_id

        """
        pass

    def test_app_role_read_secret_id_bound_cidrs(self) -> None:
        """Test case for app_role_read_secret_id_bound_cidrs

        """
        pass

    def test_app_role_read_secret_id_num_uses(self) -> None:
        """Test case for app_role_read_secret_id_num_uses

        """
        pass

    def test_app_role_read_secret_id_ttl(self) -> None:
        """Test case for app_role_read_secret_id_ttl

        """
        pass

    def test_app_role_read_token_bound_cidrs(self) -> None:
        """Test case for app_role_read_token_bound_cidrs

        """
        pass

    def test_app_role_read_token_max_ttl(self) -> None:
        """Test case for app_role_read_token_max_ttl

        """
        pass

    def test_app_role_read_token_num_uses(self) -> None:
        """Test case for app_role_read_token_num_uses

        """
        pass

    def test_app_role_read_token_ttl(self) -> None:
        """Test case for app_role_read_token_ttl

        """
        pass

    def test_app_role_tidy_secret_id(self) -> None:
        """Test case for app_role_tidy_secret_id

        """
        pass

    def test_app_role_write_bind_secret_id(self) -> None:
        """Test case for app_role_write_bind_secret_id

        """
        pass

    def test_app_role_write_bound_cidr_list(self) -> None:
        """Test case for app_role_write_bound_cidr_list

        """
        pass

    def test_app_role_write_custom_secret_id(self) -> None:
        """Test case for app_role_write_custom_secret_id

        """
        pass

    def test_app_role_write_period(self) -> None:
        """Test case for app_role_write_period

        """
        pass

    def test_app_role_write_policies(self) -> None:
        """Test case for app_role_write_policies

        """
        pass

    def test_app_role_write_role(self) -> None:
        """Test case for app_role_write_role

        """
        pass

    def test_app_role_write_role_id(self) -> None:
        """Test case for app_role_write_role_id

        """
        pass

    def test_app_role_write_secret_id(self) -> None:
        """Test case for app_role_write_secret_id

        """
        pass

    def test_app_role_write_secret_id_bound_cidrs(self) -> None:
        """Test case for app_role_write_secret_id_bound_cidrs

        """
        pass

    def test_app_role_write_secret_id_num_uses(self) -> None:
        """Test case for app_role_write_secret_id_num_uses

        """
        pass

    def test_app_role_write_secret_id_ttl(self) -> None:
        """Test case for app_role_write_secret_id_ttl

        """
        pass

    def test_app_role_write_token_bound_cidrs(self) -> None:
        """Test case for app_role_write_token_bound_cidrs

        """
        pass

    def test_app_role_write_token_max_ttl(self) -> None:
        """Test case for app_role_write_token_max_ttl

        """
        pass

    def test_app_role_write_token_num_uses(self) -> None:
        """Test case for app_role_write_token_num_uses

        """
        pass

    def test_app_role_write_token_ttl(self) -> None:
        """Test case for app_role_write_token_ttl

        """
        pass

    def test_aws_configure_certificate(self) -> None:
        """Test case for aws_configure_certificate

        """
        pass

    def test_aws_configure_client(self) -> None:
        """Test case for aws_configure_client

        """
        pass

    def test_aws_configure_identity_access_list_tidy_operation(self) -> None:
        """Test case for aws_configure_identity_access_list_tidy_operation

        """
        pass

    def test_aws_configure_identity_integration(self) -> None:
        """Test case for aws_configure_identity_integration

        """
        pass

    def test_aws_configure_identity_whitelist_tidy_operation(self) -> None:
        """Test case for aws_configure_identity_whitelist_tidy_operation

        """
        pass

    def test_aws_configure_role_tag_blacklist_tidy_operation(self) -> None:
        """Test case for aws_configure_role_tag_blacklist_tidy_operation

        """
        pass

    def test_aws_configure_role_tag_deny_list_tidy_operation(self) -> None:
        """Test case for aws_configure_role_tag_deny_list_tidy_operation

        """
        pass

    def test_aws_delete_auth_role(self) -> None:
        """Test case for aws_delete_auth_role

        """
        pass

    def test_aws_delete_certificate_configuration(self) -> None:
        """Test case for aws_delete_certificate_configuration

        """
        pass

    def test_aws_delete_client_configuration(self) -> None:
        """Test case for aws_delete_client_configuration

        """
        pass

    def test_aws_delete_identity_access_list(self) -> None:
        """Test case for aws_delete_identity_access_list

        """
        pass

    def test_aws_delete_identity_access_list_tidy_settings(self) -> None:
        """Test case for aws_delete_identity_access_list_tidy_settings

        """
        pass

    def test_aws_delete_identity_whitelist(self) -> None:
        """Test case for aws_delete_identity_whitelist

        """
        pass

    def test_aws_delete_identity_whitelist_tidy_settings(self) -> None:
        """Test case for aws_delete_identity_whitelist_tidy_settings

        """
        pass

    def test_aws_delete_role_tag_blacklist(self) -> None:
        """Test case for aws_delete_role_tag_blacklist

        """
        pass

    def test_aws_delete_role_tag_blacklist_tidy_settings(self) -> None:
        """Test case for aws_delete_role_tag_blacklist_tidy_settings

        """
        pass

    def test_aws_delete_role_tag_deny_list(self) -> None:
        """Test case for aws_delete_role_tag_deny_list

        """
        pass

    def test_aws_delete_role_tag_deny_list_tidy_settings(self) -> None:
        """Test case for aws_delete_role_tag_deny_list_tidy_settings

        """
        pass

    def test_aws_delete_sts_role(self) -> None:
        """Test case for aws_delete_sts_role

        """
        pass

    def test_aws_list_auth_roles(self) -> None:
        """Test case for aws_list_auth_roles

        """
        pass

    def test_aws_list_auth_roles2(self) -> None:
        """Test case for aws_list_auth_roles2

        """
        pass

    def test_aws_list_certificate_configurations(self) -> None:
        """Test case for aws_list_certificate_configurations

        """
        pass

    def test_aws_list_identity_access_list(self) -> None:
        """Test case for aws_list_identity_access_list

        """
        pass

    def test_aws_list_identity_whitelist(self) -> None:
        """Test case for aws_list_identity_whitelist

        """
        pass

    def test_aws_list_role_tag_blacklists(self) -> None:
        """Test case for aws_list_role_tag_blacklists

        """
        pass

    def test_aws_list_role_tag_deny_lists(self) -> None:
        """Test case for aws_list_role_tag_deny_lists

        """
        pass

    def test_aws_list_sts_role_relationships(self) -> None:
        """Test case for aws_list_sts_role_relationships

        """
        pass

    def test_aws_login(self) -> None:
        """Test case for aws_login

        """
        pass

    def test_aws_read_auth_role(self) -> None:
        """Test case for aws_read_auth_role

        """
        pass

    def test_aws_read_certificate_configuration(self) -> None:
        """Test case for aws_read_certificate_configuration

        """
        pass

    def test_aws_read_client_configuration(self) -> None:
        """Test case for aws_read_client_configuration

        """
        pass

    def test_aws_read_identity_access_list(self) -> None:
        """Test case for aws_read_identity_access_list

        """
        pass

    def test_aws_read_identity_access_list_tidy_settings(self) -> None:
        """Test case for aws_read_identity_access_list_tidy_settings

        """
        pass

    def test_aws_read_identity_integration_configuration(self) -> None:
        """Test case for aws_read_identity_integration_configuration

        """
        pass

    def test_aws_read_identity_whitelist(self) -> None:
        """Test case for aws_read_identity_whitelist

        """
        pass

    def test_aws_read_identity_whitelist_tidy_settings(self) -> None:
        """Test case for aws_read_identity_whitelist_tidy_settings

        """
        pass

    def test_aws_read_role_tag_blacklist(self) -> None:
        """Test case for aws_read_role_tag_blacklist

        """
        pass

    def test_aws_read_role_tag_blacklist_tidy_settings(self) -> None:
        """Test case for aws_read_role_tag_blacklist_tidy_settings

        """
        pass

    def test_aws_read_role_tag_deny_list(self) -> None:
        """Test case for aws_read_role_tag_deny_list

        """
        pass

    def test_aws_read_role_tag_deny_list_tidy_settings(self) -> None:
        """Test case for aws_read_role_tag_deny_list_tidy_settings

        """
        pass

    def test_aws_read_sts_role(self) -> None:
        """Test case for aws_read_sts_role

        """
        pass

    def test_aws_rotate_root_credentials(self) -> None:
        """Test case for aws_rotate_root_credentials

        """
        pass

    def test_aws_tidy_identity_access_list(self) -> None:
        """Test case for aws_tidy_identity_access_list

        """
        pass

    def test_aws_tidy_identity_whitelist(self) -> None:
        """Test case for aws_tidy_identity_whitelist

        """
        pass

    def test_aws_tidy_role_tag_blacklist(self) -> None:
        """Test case for aws_tidy_role_tag_blacklist

        """
        pass

    def test_aws_tidy_role_tag_deny_list(self) -> None:
        """Test case for aws_tidy_role_tag_deny_list

        """
        pass

    def test_aws_write_auth_role(self) -> None:
        """Test case for aws_write_auth_role

        """
        pass

    def test_aws_write_role_tag(self) -> None:
        """Test case for aws_write_role_tag

        """
        pass

    def test_aws_write_role_tag_blacklist(self) -> None:
        """Test case for aws_write_role_tag_blacklist

        """
        pass

    def test_aws_write_role_tag_deny_list(self) -> None:
        """Test case for aws_write_role_tag_deny_list

        """
        pass

    def test_aws_write_sts_role(self) -> None:
        """Test case for aws_write_sts_role

        """
        pass

    def test_azure_configure_auth(self) -> None:
        """Test case for azure_configure_auth

        """
        pass

    def test_azure_delete_auth_configuration(self) -> None:
        """Test case for azure_delete_auth_configuration

        """
        pass

    def test_azure_delete_auth_role(self) -> None:
        """Test case for azure_delete_auth_role

        """
        pass

    def test_azure_list_auth_roles(self) -> None:
        """Test case for azure_list_auth_roles

        """
        pass

    def test_azure_login(self) -> None:
        """Test case for azure_login

        """
        pass

    def test_azure_read_auth_configuration(self) -> None:
        """Test case for azure_read_auth_configuration

        """
        pass

    def test_azure_read_auth_role(self) -> None:
        """Test case for azure_read_auth_role

        """
        pass

    def test_azure_rotate_root_credentials(self) -> None:
        """Test case for azure_rotate_root_credentials

        """
        pass

    def test_azure_write_auth_role(self) -> None:
        """Test case for azure_write_auth_role

        """
        pass

    def test_centrify_configure(self) -> None:
        """Test case for centrify_configure

        """
        pass

    def test_centrify_login(self) -> None:
        """Test case for centrify_login

        Log in with a username and password.
        """
        pass

    def test_centrify_read_configuration(self) -> None:
        """Test case for centrify_read_configuration

        """
        pass

    def test_cert_configure(self) -> None:
        """Test case for cert_configure

        """
        pass

    def test_cert_delete_certificate(self) -> None:
        """Test case for cert_delete_certificate

        Manage trusted certificates used for authentication.
        """
        pass

    def test_cert_delete_crl(self) -> None:
        """Test case for cert_delete_crl

        Manage Certificate Revocation Lists checked during authentication.
        """
        pass

    def test_cert_list_certificates(self) -> None:
        """Test case for cert_list_certificates

        Manage trusted certificates used for authentication.
        """
        pass

    def test_cert_list_crls(self) -> None:
        """Test case for cert_list_crls

        """
        pass

    def test_cert_login(self) -> None:
        """Test case for cert_login

        """
        pass

    def test_cert_read_certificate(self) -> None:
        """Test case for cert_read_certificate

        Manage trusted certificates used for authentication.
        """
        pass

    def test_cert_read_configuration(self) -> None:
        """Test case for cert_read_configuration

        """
        pass

    def test_cert_read_crl(self) -> None:
        """Test case for cert_read_crl

        Manage Certificate Revocation Lists checked during authentication.
        """
        pass

    def test_cert_write_certificate(self) -> None:
        """Test case for cert_write_certificate

        Manage trusted certificates used for authentication.
        """
        pass

    def test_cert_write_crl(self) -> None:
        """Test case for cert_write_crl

        Manage Certificate Revocation Lists checked during authentication.
        """
        pass

    def test_cloud_foundry_configure(self) -> None:
        """Test case for cloud_foundry_configure

        """
        pass

    def test_cloud_foundry_delete_configuration(self) -> None:
        """Test case for cloud_foundry_delete_configuration

        """
        pass

    def test_cloud_foundry_delete_role(self) -> None:
        """Test case for cloud_foundry_delete_role

        """
        pass

    def test_cloud_foundry_list_roles(self) -> None:
        """Test case for cloud_foundry_list_roles

        """
        pass

    def test_cloud_foundry_login(self) -> None:
        """Test case for cloud_foundry_login

        """
        pass

    def test_cloud_foundry_read_configuration(self) -> None:
        """Test case for cloud_foundry_read_configuration

        """
        pass

    def test_cloud_foundry_read_role(self) -> None:
        """Test case for cloud_foundry_read_role

        """
        pass

    def test_cloud_foundry_write_role(self) -> None:
        """Test case for cloud_foundry_write_role

        """
        pass

    def test_github_configure(self) -> None:
        """Test case for github_configure

        """
        pass

    def test_github_delete_team_mapping(self) -> None:
        """Test case for github_delete_team_mapping

        Read/write/delete a single teams mapping
        """
        pass

    def test_github_delete_user_mapping(self) -> None:
        """Test case for github_delete_user_mapping

        Read/write/delete a single users mapping
        """
        pass

    def test_github_list_teams(self) -> None:
        """Test case for github_list_teams

        Read mappings for teams
        """
        pass

    def test_github_list_teams2(self) -> None:
        """Test case for github_list_teams2

        Read mappings for teams
        """
        pass

    def test_github_list_users(self) -> None:
        """Test case for github_list_users

        Read mappings for users
        """
        pass

    def test_github_list_users2(self) -> None:
        """Test case for github_list_users2

        Read mappings for users
        """
        pass

    def test_github_login(self) -> None:
        """Test case for github_login

        """
        pass

    def test_github_read_configuration(self) -> None:
        """Test case for github_read_configuration

        """
        pass

    def test_github_read_team_mapping(self) -> None:
        """Test case for github_read_team_mapping

        Read/write/delete a single teams mapping
        """
        pass

    def test_github_read_user_mapping(self) -> None:
        """Test case for github_read_user_mapping

        Read/write/delete a single users mapping
        """
        pass

    def test_github_write_team_mapping(self) -> None:
        """Test case for github_write_team_mapping

        Read/write/delete a single teams mapping
        """
        pass

    def test_github_write_user_mapping(self) -> None:
        """Test case for github_write_user_mapping

        Read/write/delete a single users mapping
        """
        pass

    def test_google_cloud_configure_auth(self) -> None:
        """Test case for google_cloud_configure_auth

        """
        pass

    def test_google_cloud_delete_role(self) -> None:
        """Test case for google_cloud_delete_role

        Create a GCP role with associated policies and required attributes.
        """
        pass

    def test_google_cloud_edit_labels_for_role(self) -> None:
        """Test case for google_cloud_edit_labels_for_role

        Add or remove labels for an existing 'gce' role
        """
        pass

    def test_google_cloud_edit_service_accounts_for_role(self) -> None:
        """Test case for google_cloud_edit_service_accounts_for_role

        Add or remove service accounts for an existing `iam` role
        """
        pass

    def test_google_cloud_list_roles(self) -> None:
        """Test case for google_cloud_list_roles

        Lists all the roles that are registered with Vault.
        """
        pass

    def test_google_cloud_list_roles2(self) -> None:
        """Test case for google_cloud_list_roles2

        Lists all the roles that are registered with Vault.
        """
        pass

    def test_google_cloud_login(self) -> None:
        """Test case for google_cloud_login

        """
        pass

    def test_google_cloud_read_auth_configuration(self) -> None:
        """Test case for google_cloud_read_auth_configuration

        """
        pass

    def test_google_cloud_read_role(self) -> None:
        """Test case for google_cloud_read_role

        Create a GCP role with associated policies and required attributes.
        """
        pass

    def test_google_cloud_write_role(self) -> None:
        """Test case for google_cloud_write_role

        Create a GCP role with associated policies and required attributes.
        """
        pass

    def test_jwt_configure(self) -> None:
        """Test case for jwt_configure

        Configure the JWT authentication backend.
        """
        pass

    def test_jwt_delete_role(self) -> None:
        """Test case for jwt_delete_role

        Delete an existing role.
        """
        pass

    def test_jwt_list_roles(self) -> None:
        """Test case for jwt_list_roles

        Lists all the roles registered with the backend.
        """
        pass

    def test_jwt_login(self) -> None:
        """Test case for jwt_login

        Authenticates to Vault using a JWT (or OIDC) token.
        """
        pass

    def test_jwt_oidc_callback(self) -> None:
        """Test case for jwt_oidc_callback

        Callback endpoint to complete an OIDC login.
        """
        pass

    def test_jwt_oidc_callback_form_post(self) -> None:
        """Test case for jwt_oidc_callback_form_post

        Callback endpoint to handle form_posts.
        """
        pass

    def test_jwt_oidc_request_authorization_url(self) -> None:
        """Test case for jwt_oidc_request_authorization_url

        Request an authorization URL to start an OIDC login flow.
        """
        pass

    def test_jwt_read_configuration(self) -> None:
        """Test case for jwt_read_configuration

        Read the current JWT authentication backend configuration.
        """
        pass

    def test_jwt_read_role(self) -> None:
        """Test case for jwt_read_role

        Read an existing role.
        """
        pass

    def test_jwt_write_role(self) -> None:
        """Test case for jwt_write_role

        Register an role with the backend.
        """
        pass

    def test_kerberos_configure(self) -> None:
        """Test case for kerberos_configure

        """
        pass

    def test_kerberos_configure_ldap(self) -> None:
        """Test case for kerberos_configure_ldap

        """
        pass

    def test_kerberos_delete_group(self) -> None:
        """Test case for kerberos_delete_group

        """
        pass

    def test_kerberos_list_groups(self) -> None:
        """Test case for kerberos_list_groups

        """
        pass

    def test_kerberos_login(self) -> None:
        """Test case for kerberos_login

        """
        pass

    def test_kerberos_login2(self) -> None:
        """Test case for kerberos_login2

        """
        pass

    def test_kerberos_read_configuration(self) -> None:
        """Test case for kerberos_read_configuration

        """
        pass

    def test_kerberos_read_group(self) -> None:
        """Test case for kerberos_read_group

        """
        pass

    def test_kerberos_read_ldap_configuration(self) -> None:
        """Test case for kerberos_read_ldap_configuration

        """
        pass

    def test_kerberos_write_group(self) -> None:
        """Test case for kerberos_write_group

        """
        pass

    def test_kubernetes_configure_auth(self) -> None:
        """Test case for kubernetes_configure_auth

        """
        pass

    def test_kubernetes_delete_auth_role(self) -> None:
        """Test case for kubernetes_delete_auth_role

        Register an role with the backend.
        """
        pass

    def test_kubernetes_list_auth_roles(self) -> None:
        """Test case for kubernetes_list_auth_roles

        Lists all the roles registered with the backend.
        """
        pass

    def test_kubernetes_login(self) -> None:
        """Test case for kubernetes_login

        Authenticates Kubernetes service accounts with Vault.
        """
        pass

    def test_kubernetes_read_auth_configuration(self) -> None:
        """Test case for kubernetes_read_auth_configuration

        """
        pass

    def test_kubernetes_read_auth_role(self) -> None:
        """Test case for kubernetes_read_auth_role

        Register an role with the backend.
        """
        pass

    def test_kubernetes_write_auth_role(self) -> None:
        """Test case for kubernetes_write_auth_role

        Register an role with the backend.
        """
        pass

    def test_ldap_configure_auth(self) -> None:
        """Test case for ldap_configure_auth

        """
        pass

    def test_ldap_delete_group(self) -> None:
        """Test case for ldap_delete_group

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_ldap_delete_user(self) -> None:
        """Test case for ldap_delete_user

        Manage users allowed to authenticate.
        """
        pass

    def test_ldap_list_groups(self) -> None:
        """Test case for ldap_list_groups

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_ldap_list_users(self) -> None:
        """Test case for ldap_list_users

        Manage users allowed to authenticate.
        """
        pass

    def test_ldap_login(self) -> None:
        """Test case for ldap_login

        Log in with a username and password.
        """
        pass

    def test_ldap_read_auth_configuration(self) -> None:
        """Test case for ldap_read_auth_configuration

        """
        pass

    def test_ldap_read_group(self) -> None:
        """Test case for ldap_read_group

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_ldap_read_user(self) -> None:
        """Test case for ldap_read_user

        Manage users allowed to authenticate.
        """
        pass

    def test_ldap_write_group(self) -> None:
        """Test case for ldap_write_group

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_ldap_write_user(self) -> None:
        """Test case for ldap_write_user

        Manage users allowed to authenticate.
        """
        pass

    def test_oci_configure(self) -> None:
        """Test case for oci_configure

        """
        pass

    def test_oci_delete_configuration(self) -> None:
        """Test case for oci_delete_configuration

        """
        pass

    def test_oci_delete_role(self) -> None:
        """Test case for oci_delete_role

        Create a role and associate policies to it.
        """
        pass

    def test_oci_list_roles(self) -> None:
        """Test case for oci_list_roles

        Lists all the roles that are registered with Vault.
        """
        pass

    def test_oci_login(self) -> None:
        """Test case for oci_login

        Authenticates to Vault using OCI credentials
        """
        pass

    def test_oci_read_configuration(self) -> None:
        """Test case for oci_read_configuration

        """
        pass

    def test_oci_read_role(self) -> None:
        """Test case for oci_read_role

        Create a role and associate policies to it.
        """
        pass

    def test_oci_write_role(self) -> None:
        """Test case for oci_write_role

        Create a role and associate policies to it.
        """
        pass

    def test_okta_configure(self) -> None:
        """Test case for okta_configure

        """
        pass

    def test_okta_delete_group(self) -> None:
        """Test case for okta_delete_group

        Manage users allowed to authenticate.
        """
        pass

    def test_okta_delete_user(self) -> None:
        """Test case for okta_delete_user

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_okta_list_groups(self) -> None:
        """Test case for okta_list_groups

        Manage users allowed to authenticate.
        """
        pass

    def test_okta_list_users(self) -> None:
        """Test case for okta_list_users

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_okta_login(self) -> None:
        """Test case for okta_login

        Log in with a username and password.
        """
        pass

    def test_okta_read_configuration(self) -> None:
        """Test case for okta_read_configuration

        """
        pass

    def test_okta_read_group(self) -> None:
        """Test case for okta_read_group

        Manage users allowed to authenticate.
        """
        pass

    def test_okta_read_user(self) -> None:
        """Test case for okta_read_user

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_okta_verify(self) -> None:
        """Test case for okta_verify

        """
        pass

    def test_okta_write_group(self) -> None:
        """Test case for okta_write_group

        Manage users allowed to authenticate.
        """
        pass

    def test_okta_write_user(self) -> None:
        """Test case for okta_write_user

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_radius_configure(self) -> None:
        """Test case for radius_configure

        """
        pass

    def test_radius_delete_user(self) -> None:
        """Test case for radius_delete_user

        Manage users allowed to authenticate.
        """
        pass

    def test_radius_list_users(self) -> None:
        """Test case for radius_list_users

        Manage users allowed to authenticate.
        """
        pass

    def test_radius_login(self) -> None:
        """Test case for radius_login

        Log in with a username and password.
        """
        pass

    def test_radius_login_with_username(self) -> None:
        """Test case for radius_login_with_username

        Log in with a username and password.
        """
        pass

    def test_radius_read_configuration(self) -> None:
        """Test case for radius_read_configuration

        """
        pass

    def test_radius_read_user(self) -> None:
        """Test case for radius_read_user

        Manage users allowed to authenticate.
        """
        pass

    def test_radius_write_user(self) -> None:
        """Test case for radius_write_user

        Manage users allowed to authenticate.
        """
        pass

    def test_token_create(self) -> None:
        """Test case for token_create

        The token create path is used to create new tokens.
        """
        pass

    def test_token_create_against_role(self) -> None:
        """Test case for token_create_against_role

        This token create path is used to create new tokens adhering to the given role.
        """
        pass

    def test_token_create_orphan(self) -> None:
        """Test case for token_create_orphan

        The token create path is used to create new orphan tokens.
        """
        pass

    def test_token_delete_role(self) -> None:
        """Test case for token_delete_role

        """
        pass

    def test_token_list_accessors(self) -> None:
        """Test case for token_list_accessors

        List token accessors, which can then be be used to iterate and discover their properties or revoke them. Because this can be used to cause a denial of service, this endpoint requires 'sudo' capability in addition to 'list'.
        """
        pass

    def test_token_list_roles(self) -> None:
        """Test case for token_list_roles

        This endpoint lists configured roles.
        """
        pass

    def test_token_look_up(self) -> None:
        """Test case for token_look_up

        """
        pass

    def test_token_look_up2(self) -> None:
        """Test case for token_look_up2

        """
        pass

    def test_token_look_up_accessor(self) -> None:
        """Test case for token_look_up_accessor

        This endpoint will lookup a token associated with the given accessor and its properties. Response will not contain the token ID.
        """
        pass

    def test_token_look_up_self(self) -> None:
        """Test case for token_look_up_self

        """
        pass

    def test_token_look_up_self2(self) -> None:
        """Test case for token_look_up_self2

        """
        pass

    def test_token_read_role(self) -> None:
        """Test case for token_read_role

        """
        pass

    def test_token_renew(self) -> None:
        """Test case for token_renew

        This endpoint will renew the given token and prevent expiration.
        """
        pass

    def test_token_renew_accessor(self) -> None:
        """Test case for token_renew_accessor

        This endpoint will renew a token associated with the given accessor and its properties. Response will not contain the token ID.
        """
        pass

    def test_token_renew_self(self) -> None:
        """Test case for token_renew_self

        This endpoint will renew the token used to call it and prevent expiration.
        """
        pass

    def test_token_revoke(self) -> None:
        """Test case for token_revoke

        This endpoint will delete the given token and all of its child tokens.
        """
        pass

    def test_token_revoke_accessor(self) -> None:
        """Test case for token_revoke_accessor

        This endpoint will delete the token associated with the accessor and all of its child tokens.
        """
        pass

    def test_token_revoke_orphan(self) -> None:
        """Test case for token_revoke_orphan

        This endpoint will delete the token and orphan its child tokens.
        """
        pass

    def test_token_revoke_self(self) -> None:
        """Test case for token_revoke_self

        This endpoint will delete the token used to call it and all of its child tokens.
        """
        pass

    def test_token_tidy(self) -> None:
        """Test case for token_tidy

        This endpoint performs cleanup tasks that can be run if certain error conditions have occurred.
        """
        pass

    def test_token_write_role(self) -> None:
        """Test case for token_write_role

        """
        pass

    def test_userpass_delete_user(self) -> None:
        """Test case for userpass_delete_user

        Manage users allowed to authenticate.
        """
        pass

    def test_userpass_list_users(self) -> None:
        """Test case for userpass_list_users

        Manage users allowed to authenticate.
        """
        pass

    def test_userpass_login(self) -> None:
        """Test case for userpass_login

        Log in with a username and password.
        """
        pass

    def test_userpass_read_user(self) -> None:
        """Test case for userpass_read_user

        Manage users allowed to authenticate.
        """
        pass

    def test_userpass_reset_password(self) -> None:
        """Test case for userpass_reset_password

        Reset user's password.
        """
        pass

    def test_userpass_update_policies(self) -> None:
        """Test case for userpass_update_policies

        Update the policies associated with the username.
        """
        pass

    def test_userpass_write_user(self) -> None:
        """Test case for userpass_write_user

        Manage users allowed to authenticate.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TransitVerifyWithAlgorithmRequest(BaseModel):
    """
    TransitVerifyWithAlgorithmRequest
    """ # noqa: E501
    algorithm: Optional[StrictStr] = Field(default='sha2-256', description="Deprecated: use \"hash_algorithm\" instead.")
    batch_input: Optional[List[Dict[str, Any]]] = Field(default=None, description="Specifies a list of items for processing. When this parameter is set, any supplied 'input', 'hmac' or 'signature' parameters will be ignored. Responses are returned in the 'batch_results' array component of the 'data' element of the response. Any batch output will preserve the order of the batch input")
    context: Optional[StrictStr] = Field(default=None, description="Base64 encoded context for key derivation. Required if key derivation is enabled; currently only available with ed25519 keys.")
    hash_algorithm: Optional[StrictStr] = Field(default='sha2-256', description="Hash algorithm to use (POST body parameter). Valid values are: * sha1 * sha2-224 * sha2-256 * sha2-384 * sha2-512 * sha3-224 * sha3-256 * sha3-384 * sha3-512 * none Defaults to \"sha2-256\". Not valid for all key types. See note about none on signing path.")
    hmac: Optional[StrictStr] = Field(default=None, description="The HMAC, including vault header/key version")
    input: Optional[StrictStr] = Field(default=None, description="The base64-encoded input data to verify")
    marshaling_algorithm: Optional[StrictStr] = Field(default='asn1', description="The method by which to unmarshal the signature when verifying. The default is 'asn1' which is used by openssl and X.509; can also be set to 'jws' which is used for JWT signatures in which case the signature is also expected to be url-safe base64 encoding instead of standard base64 encoding. Currently only valid for ECDSA P-256 key types\".")
    prehashed: Optional[StrictBool] = Field(default=None, description="Set to 'true' when the input is already hashed. If the key type is 'rsa-2048', 'rsa-3072' or 'rsa-4096', then the algorithm used to hash the input should be indicated by the 'algorithm' parameter.")
    salt_length: Optional[StrictStr] = Field(default='auto', description="The salt length used to sign. Currently only applies to the RSA PSS signature scheme. Options are 'auto' (the default used by Golang, causing the salt to be as large as possible when signing), 'hash' (causes the salt length to equal the length of the hash used in the signature), or an integer between the minimum and the maximum permissible salt lengths for the given RSA key size. Defaults to 'auto'.")
    signature: Optional[StrictStr] = Field(default=None, description="The signature, including vault header/key version")
    signature_algorithm: Optional[StrictStr] = Field(default=None, description="The signature algorithm to use for signature verification. Currently only applies to RSA key types. Options are 'pss' or 'pkcs1v15'. Defaults to 'pss'")
    __properties: ClassVar[List[str]] = ["algorithm", "batch_input", "context", "hash_algorithm", "hmac", "input", "marshaling_algorithm", "prehashed", "salt_length", "signature", "signature_algorithm"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TransitVerifyWithAlgorithmRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TransitVerifyWithAlgorithmRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "algorithm": obj.get("algorithm") if obj.get("algorithm") is not None else 'sha2-256',
            "batch_input": obj.get("batch_input"),
            "context": obj.get("context"),
            "hash_algorithm": obj.get("hash_algorithm") if obj.get("hash_algorithm") is not None else 'sha2-256',
            "hmac": obj.get("hmac"),
            "input": obj.get("input"),
            "marshaling_algorithm": obj.get("marshaling_algorithm") if obj.get("marshaling_algorithm") is not None else 'asn1',
            "prehashed": obj.get("prehashed"),
            "salt_length": obj.get("salt_length") if obj.get("salt_length") is not None else 'auto',
            "signature": obj.get("signature"),
            "signature_algorithm": obj.get("signature_algorithm")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.pki_write_role_response import PkiWriteRoleResponse

class TestPkiWriteRoleResponse(unittest.TestCase):
    """PkiWriteRoleResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PkiWriteRoleResponse:
        """Test PkiWriteRoleResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PkiWriteRoleResponse`
        """
        model = PkiWriteRoleResponse()
        if include_optional:
            return PkiWriteRoleResponse(
                allow_any_name = True,
                allow_bare_domains = True,
                allow_glob_domains = True,
                allow_ip_sans = True,
                allow_localhost = True,
                allow_subdomains = True,
                allow_token_displayname = True,
                allow_wildcard_certificates = True,
                allowed_domains = [
                    ''
                    ],
                allowed_domains_template = True,
                allowed_other_sans = [
                    ''
                    ],
                allowed_serial_numbers = [
                    ''
                    ],
                allowed_uri_sans = [
                    ''
                    ],
                allowed_uri_sans_template = True,
                allowed_user_ids = [
                    ''
                    ],
                basic_constraints_valid_for_non_ca = True,
                client_flag = True,
                cn_validations = [
                    ''
                    ],
                code_signing_flag = True,
                country = [
                    ''
                    ],
                email_protection_flag = True,
                enforce_hostnames = True,
                ext_key_usage = [
                    ''
                    ],
                ext_key_usage_oids = [
                    ''
                    ],
                generate_lease = True,
                issuer_ref = '',
                key_bits = 56,
                key_type = '',
                key_usage = [
                    ''
                    ],
                locality = [
                    ''
                    ],
                max_ttl = 56,
                no_store = True,
                not_after = '',
                not_before_duration = 56,
                organization = [
                    ''
                    ],
                ou = [
                    ''
                    ],
                policy_identifiers = [
                    ''
                    ],
                postal_code = [
                    ''
                    ],
                province = [
                    ''
                    ],
                require_cn = True,
                server_flag = True,
                signature_bits = 56,
                street_address = [
                    ''
                    ],
                ttl = 56,
                use_csr_common_name = True,
                use_csr_sans = True,
                use_pss = True
            )
        else:
            return PkiWriteRoleResponse(
        )
        """

    def testPkiWriteRoleResponse(self):
        """Test PkiWriteRoleResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AzureLoginRequest(BaseModel):
    """
    AzureLoginRequest
    """ # noqa: E501
    jwt: Optional[StrictStr] = Field(default=None, description="A signed JWT")
    resource_group_name: Optional[StrictStr] = Field(default=None, description="The resource group from the instance.")
    resource_id: Optional[StrictStr] = Field(default=None, description="The fully qualified ID of the resource, includingthe resource name and resource type. Use the format, /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}. This value is ignored if vm_name or vmss_name is specified.")
    role: Optional[StrictStr] = Field(default=None, description="The token role.")
    subscription_id: Optional[StrictStr] = Field(default=None, description="The subscription id for the instance.")
    vm_name: Optional[StrictStr] = Field(default=None, description="The name of the virtual machine. This value is ignored if vmss_name is specified.")
    vmss_name: Optional[StrictStr] = Field(default=None, description="The name of the virtual machine scale set the instance is in.")
    __properties: ClassVar[List[str]] = ["jwt", "resource_group_name", "resource_id", "role", "subscription_id", "vm_name", "vmss_name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AzureLoginRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AzureLoginRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "jwt": obj.get("jwt"),
            "resource_group_name": obj.get("resource_group_name"),
            "resource_id": obj.get("resource_id"),
            "role": obj.get("role"),
            "subscription_id": obj.get("subscription_id"),
            "vm_name": obj.get("vm_name"),
            "vmss_name": obj.get("vmss_name")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiConfigureAutoTidyRequest(BaseModel):
    """
    PkiConfigureAutoTidyRequest
    """ # noqa: E501
    acme_account_safety_buffer: Optional[StrictStr] = Field(default='2592000', description="The amount of time that must pass after creation that an account with no orders is marked revoked, and the amount of time after being marked revoked or deactivated.")
    enabled: Optional[StrictBool] = Field(default=None, description="Set to true to enable automatic tidy operations.")
    interval_duration: Optional[StrictStr] = Field(default='43200', description="Interval at which to run an auto-tidy operation. This is the time between tidy invocations (after one finishes to the start of the next). Running a manual tidy will reset this duration.")
    issuer_safety_buffer: Optional[StrictStr] = Field(default='31536000', description="The amount of extra time that must have passed beyond issuer's expiration before it is removed from the backend storage. Defaults to 8760 hours (1 year).")
    maintain_stored_certificate_counts: Optional[StrictBool] = Field(default=False, description="This configures whether stored certificates are counted upon initialization of the backend, and whether during normal operation, a running count of certificates stored is maintained.")
    pause_duration: Optional[StrictStr] = Field(default='0s', description="The amount of time to wait between processing certificates. This allows operators to change the execution profile of tidy to take consume less resources by slowing down how long it takes to run. Note that the entire list of certificates will be stored in memory during the entire tidy operation, but resources to read/process/update existing entries will be spread out over a greater period of time. By default this is zero seconds.")
    publish_stored_certificate_count_metrics: Optional[StrictBool] = Field(default=False, description="This configures whether the stored certificate count is published to the metrics consumer. It does not affect if the stored certificate count is maintained, and if maintained, it will be available on the tidy-status endpoint.")
    revocation_queue_safety_buffer: Optional[StrictStr] = Field(default='172800', description="The amount of time that must pass from the cross-cluster revocation request being initiated to when it will be slated for removal. Setting this too low may remove valid revocation requests before the owning cluster has a chance to process them, especially if the cluster is offline.")
    safety_buffer: Optional[StrictStr] = Field(default='259200', description="The amount of extra time that must have passed beyond certificate expiration before it is removed from the backend storage and/or revocation list. Defaults to 72 hours.")
    tidy_acme: Optional[StrictBool] = Field(default=False, description="Set to true to enable tidying ACME accounts, orders and authorizations. ACME orders are tidied (deleted) safety_buffer after the certificate associated with them expires, or after the order and relevant authorizations have expired if no certificate was produced. Authorizations are tidied with the corresponding order. When a valid ACME Account is at least acme_account_safety_buffer old, and has no remaining orders associated with it, the account is marked as revoked. After another acme_account_safety_buffer has passed from the revocation or deactivation date, a revoked or deactivated ACME account is deleted.")
    tidy_cert_store: Optional[StrictBool] = Field(default=None, description="Set to true to enable tidying up the certificate store")
    tidy_cross_cluster_revoked_certs: Optional[StrictBool] = Field(default=None, description="Set to true to enable tidying up the cross-cluster revoked certificate store. Only runs on the active primary node.")
    tidy_expired_issuers: Optional[StrictBool] = Field(default=None, description="Set to true to automatically remove expired issuers past the issuer_safety_buffer. No keys will be removed as part of this operation.")
    tidy_move_legacy_ca_bundle: Optional[StrictBool] = Field(default=None, description="Set to true to move the legacy ca_bundle from /config/ca_bundle to /config/ca_bundle.bak. This prevents downgrades to pre-Vault 1.11 versions (as older PKI engines do not know about the new multi-issuer storage layout), but improves the performance on seal wrapped PKI mounts. This will only occur if at least issuer_safety_buffer time has occurred after the initial storage migration. This backup is saved in case of an issue in future migrations. Operators may consider removing it via sys/raw if they desire. The backup will be removed via a DELETE /root call, but note that this removes ALL issuers within the mount (and is thus not desirable in most operational scenarios).")
    tidy_revocation_list: Optional[StrictBool] = Field(default=None, description="Deprecated; synonym for 'tidy_revoked_certs")
    tidy_revocation_queue: Optional[StrictBool] = Field(default=False, description="Set to true to remove stale revocation queue entries that haven't been confirmed by any active cluster. Only runs on the active primary node")
    tidy_revoked_cert_issuer_associations: Optional[StrictBool] = Field(default=None, description="Set to true to validate issuer associations on revocation entries. This helps increase the performance of CRL building and OCSP responses.")
    tidy_revoked_certs: Optional[StrictBool] = Field(default=None, description="Set to true to expire all revoked and expired certificates, removing them both from the CRL and from storage. The CRL will be rotated if this causes any values to be removed.")
    __properties: ClassVar[List[str]] = ["acme_account_safety_buffer", "enabled", "interval_duration", "issuer_safety_buffer", "maintain_stored_certificate_counts", "pause_duration", "publish_stored_certificate_count_metrics", "revocation_queue_safety_buffer", "safety_buffer", "tidy_acme", "tidy_cert_store", "tidy_cross_cluster_revoked_certs", "tidy_expired_issuers", "tidy_move_legacy_ca_bundle", "tidy_revocation_list", "tidy_revocation_queue", "tidy_revoked_cert_issuer_associations", "tidy_revoked_certs"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiConfigureAutoTidyRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiConfigureAutoTidyRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "acme_account_safety_buffer": obj.get("acme_account_safety_buffer") if obj.get("acme_account_safety_buffer") is not None else '2592000',
            "enabled": obj.get("enabled"),
            "interval_duration": obj.get("interval_duration") if obj.get("interval_duration") is not None else '43200',
            "issuer_safety_buffer": obj.get("issuer_safety_buffer") if obj.get("issuer_safety_buffer") is not None else '31536000',
            "maintain_stored_certificate_counts": obj.get("maintain_stored_certificate_counts") if obj.get("maintain_stored_certificate_counts") is not None else False,
            "pause_duration": obj.get("pause_duration") if obj.get("pause_duration") is not None else '0s',
            "publish_stored_certificate_count_metrics": obj.get("publish_stored_certificate_count_metrics") if obj.get("publish_stored_certificate_count_metrics") is not None else False,
            "revocation_queue_safety_buffer": obj.get("revocation_queue_safety_buffer") if obj.get("revocation_queue_safety_buffer") is not None else '172800',
            "safety_buffer": obj.get("safety_buffer") if obj.get("safety_buffer") is not None else '259200',
            "tidy_acme": obj.get("tidy_acme") if obj.get("tidy_acme") is not None else False,
            "tidy_cert_store": obj.get("tidy_cert_store"),
            "tidy_cross_cluster_revoked_certs": obj.get("tidy_cross_cluster_revoked_certs"),
            "tidy_expired_issuers": obj.get("tidy_expired_issuers"),
            "tidy_move_legacy_ca_bundle": obj.get("tidy_move_legacy_ca_bundle"),
            "tidy_revocation_list": obj.get("tidy_revocation_list"),
            "tidy_revocation_queue": obj.get("tidy_revocation_queue") if obj.get("tidy_revocation_queue") is not None else False,
            "tidy_revoked_cert_issuer_associations": obj.get("tidy_revoked_cert_issuer_associations"),
            "tidy_revoked_certs": obj.get("tidy_revoked_certs")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AwsWriteAuthRoleRequest(BaseModel):
    """
    AwsWriteAuthRoleRequest
    """ # noqa: E501
    allow_instance_migration: Optional[StrictBool] = Field(default=False, description="If set, allows migration of the underlying instance where the client resides. This keys off of pendingTime in the metadata document, so essentially, this disables the client nonce check whenever the instance is migrated to a new host and pendingTime is newer than the previously-remembered time. Use with caution. This is only checked when auth_type is ec2.")
    auth_type: Optional[StrictStr] = Field(default=None, description="The auth_type permitted to authenticate to this role. Must be one of iam or ec2 and cannot be changed after role creation.")
    bound_account_id: Optional[List[StrictStr]] = Field(default=None, description="If set, defines a constraint on the EC2 instances that the account ID in its identity document to match one of the IDs specified by this parameter. This is only applicable when auth_type is ec2 or inferred_entity_type is ec2_instance.")
    bound_ami_id: Optional[List[StrictStr]] = Field(default=None, description="If set, defines a constraint on the EC2 instances that they should be using one of the AMI IDs specified by this parameter. This is only applicable when auth_type is ec2 or inferred_entity_type is ec2_instance.")
    bound_ec2_instance_id: Optional[List[StrictStr]] = Field(default=None, description="If set, defines a constraint on the EC2 instances to have one of the given instance IDs. Can be a list or comma-separated string of EC2 instance IDs. This is only applicable when auth_type is ec2 or inferred_entity_type is ec2_instance.")
    bound_iam_instance_profile_arn: Optional[List[StrictStr]] = Field(default=None, description="If set, defines a constraint on the EC2 instances to be associated with an IAM instance profile ARN which has a prefix that matches one of the values specified by this parameter. The value is prefix-matched (as though it were a glob ending in '*'). This is only applicable when auth_type is ec2 or inferred_entity_type is ec2_instance.")
    bound_iam_principal_arn: Optional[List[StrictStr]] = Field(default=None, description="ARN of the IAM principals to bind to this role. Only applicable when auth_type is iam.")
    bound_iam_role_arn: Optional[List[StrictStr]] = Field(default=None, description="If set, defines a constraint on the authenticating EC2 instance that it must match one of the IAM role ARNs specified by this parameter. The value is prefix-matched (as though it were a glob ending in '*'). The configured IAM user or EC2 instance role must be allowed to execute the 'iam:GetInstanceProfile' action if this is specified. This is only applicable when auth_type is ec2 or inferred_entity_type is ec2_instance.")
    bound_region: Optional[List[StrictStr]] = Field(default=None, description="If set, defines a constraint on the EC2 instances that the region in its identity document match one of the regions specified by this parameter. This is only applicable when auth_type is ec2.")
    bound_subnet_id: Optional[List[StrictStr]] = Field(default=None, description="If set, defines a constraint on the EC2 instance to be associated with the subnet ID that matches one of the values specified by this parameter. This is only applicable when auth_type is ec2 or inferred_entity_type is ec2_instance.")
    bound_vpc_id: Optional[List[StrictStr]] = Field(default=None, description="If set, defines a constraint on the EC2 instance to be associated with a VPC ID that matches one of the value specified by this parameter. This is only applicable when auth_type is ec2 or inferred_entity_type is ec2_instance.")
    disallow_reauthentication: Optional[StrictBool] = Field(default=False, description="If set, only allows a single token to be granted per instance ID. In order to perform a fresh login, the entry in the access list for the instance ID needs to be cleared using 'auth/aws-ec2/identity-accesslist/<instance_id>' endpoint. This is only applicable when auth_type is ec2.")
    inferred_aws_region: Optional[StrictStr] = Field(default=None, description="When auth_type is iam and inferred_entity_type is set, the region to assume the inferred entity exists in.")
    inferred_entity_type: Optional[StrictStr] = Field(default=None, description="When auth_type is iam, the AWS entity type to infer from the authenticated principal. The only supported value is ec2_instance, which will extract the EC2 instance ID from the authenticated role and apply the following restrictions specific to EC2 instances: bound_ami_id, bound_account_id, bound_iam_role_arn, bound_iam_instance_profile_arn, bound_vpc_id, bound_subnet_id. The configured EC2 client must be able to find the inferred instance ID in the results, and the instance must be running. If unable to determine the EC2 instance ID or unable to find the EC2 instance ID among running instances, then authentication will fail.")
    max_ttl: Optional[StrictStr] = Field(default=None, description="Use \"token_max_ttl\" instead. If this and \"token_max_ttl\" are both specified, only \"token_max_ttl\" will be used.")
    period: Optional[StrictStr] = Field(default=None, description="Use \"token_period\" instead. If this and \"token_period\" are both specified, only \"token_period\" will be used.")
    policies: Optional[List[StrictStr]] = Field(default=None, description="Use \"token_policies\" instead. If this and \"token_policies\" are both specified, only \"token_policies\" will be used.")
    resolve_aws_unique_ids: Optional[StrictBool] = Field(default=True, description="If set, resolve all AWS IAM ARNs into AWS's internal unique IDs. When an IAM entity (e.g., user, role, or instance profile) is deleted, then all references to it within the role will be invalidated, which prevents a new IAM entity from being created with the same name and matching the role's IAM binds. Once set, this cannot be unset.")
    role_tag: Optional[StrictStr] = Field(default='', description="If set, enables the role tags for this role. The value set for this field should be the 'key' of the tag on the EC2 instance. The 'value' of the tag should be generated using 'role/<role>/tag' endpoint. Defaults to an empty string, meaning that role tags are disabled. This is only allowed if auth_type is ec2.")
    token_bound_cidrs: Optional[List[StrictStr]] = Field(default=None, description="Comma separated string or JSON list of CIDR blocks. If set, specifies the blocks of IP addresses which are allowed to use the generated token.")
    token_explicit_max_ttl: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role carry an explicit maximum TTL. During renewal, the current maximum TTL values of the role and the mount are not checked for changes, and any updates to these values will have no effect on the token being renewed.")
    token_max_ttl: Optional[StrictStr] = Field(default=None, description="The maximum lifetime of the generated token")
    token_no_default_policy: Optional[StrictBool] = Field(default=None, description="If true, the 'default' policy will not automatically be added to generated tokens")
    token_num_uses: Optional[StrictInt] = Field(default=None, description="The maximum number of times a token may be used, a value of zero means unlimited")
    token_period: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role will have no max lifetime; instead, their renewal period will be fixed to this value. This takes an integer number of seconds, or a string duration (e.g. \"24h\").")
    token_policies: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of policies")
    token_ttl: Optional[StrictStr] = Field(default=None, description="The initial ttl of the token to generate")
    token_type: Optional[StrictStr] = Field(default='default-service', description="The type of token to generate, service or batch")
    ttl: Optional[StrictStr] = Field(default=None, description="Use \"token_ttl\" instead. If this and \"token_ttl\" are both specified, only \"token_ttl\" will be used.")
    __properties: ClassVar[List[str]] = ["allow_instance_migration", "auth_type", "bound_account_id", "bound_ami_id", "bound_ec2_instance_id", "bound_iam_instance_profile_arn", "bound_iam_principal_arn", "bound_iam_role_arn", "bound_region", "bound_subnet_id", "bound_vpc_id", "disallow_reauthentication", "inferred_aws_region", "inferred_entity_type", "max_ttl", "period", "policies", "resolve_aws_unique_ids", "role_tag", "token_bound_cidrs", "token_explicit_max_ttl", "token_max_ttl", "token_no_default_policy", "token_num_uses", "token_period", "token_policies", "token_ttl", "token_type", "ttl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AwsWriteAuthRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AwsWriteAuthRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allow_instance_migration": obj.get("allow_instance_migration") if obj.get("allow_instance_migration") is not None else False,
            "auth_type": obj.get("auth_type"),
            "bound_account_id": obj.get("bound_account_id"),
            "bound_ami_id": obj.get("bound_ami_id"),
            "bound_ec2_instance_id": obj.get("bound_ec2_instance_id"),
            "bound_iam_instance_profile_arn": obj.get("bound_iam_instance_profile_arn"),
            "bound_iam_principal_arn": obj.get("bound_iam_principal_arn"),
            "bound_iam_role_arn": obj.get("bound_iam_role_arn"),
            "bound_region": obj.get("bound_region"),
            "bound_subnet_id": obj.get("bound_subnet_id"),
            "bound_vpc_id": obj.get("bound_vpc_id"),
            "disallow_reauthentication": obj.get("disallow_reauthentication") if obj.get("disallow_reauthentication") is not None else False,
            "inferred_aws_region": obj.get("inferred_aws_region"),
            "inferred_entity_type": obj.get("inferred_entity_type"),
            "max_ttl": obj.get("max_ttl"),
            "period": obj.get("period"),
            "policies": obj.get("policies"),
            "resolve_aws_unique_ids": obj.get("resolve_aws_unique_ids") if obj.get("resolve_aws_unique_ids") is not None else True,
            "role_tag": obj.get("role_tag") if obj.get("role_tag") is not None else '',
            "token_bound_cidrs": obj.get("token_bound_cidrs"),
            "token_explicit_max_ttl": obj.get("token_explicit_max_ttl"),
            "token_max_ttl": obj.get("token_max_ttl"),
            "token_no_default_policy": obj.get("token_no_default_policy"),
            "token_num_uses": obj.get("token_num_uses"),
            "token_period": obj.get("token_period"),
            "token_policies": obj.get("token_policies"),
            "token_ttl": obj.get("token_ttl"),
            "token_type": obj.get("token_type") if obj.get("token_type") is not None else 'default-service',
            "ttl": obj.get("ttl")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class GoogleCloudKmsWriteKeyRequest(BaseModel):
    """
    GoogleCloudKmsWriteKeyRequest
    """ # noqa: E501
    algorithm: Optional[StrictStr] = Field(default=None, description="Algorithm to use for encryption, decryption, or signing. The value depends on the key purpose. The value cannot be changed after creation. For a key purpose of \"encrypt_decrypt\", the valid values are: - symmetric_encryption (default) For a key purpose of \"asymmetric_sign\", valid values are: - rsa_sign_pss_2048_sha256 - rsa_sign_pss_3072_sha256 - rsa_sign_pss_4096_sha256 - rsa_sign_pkcs1_2048_sha256 - rsa_sign_pkcs1_3072_sha256 - rsa_sign_pkcs1_4096_sha256 - ec_sign_p256_sha256 - ec_sign_p384_sha384 For a key purpose of \"asymmetric_decrypt\", valid values are: - rsa_decrypt_oaep_2048_sha256 - rsa_decrypt_oaep_3072_sha256 - rsa_decrypt_oaep_4096_sha256")
    crypto_key: Optional[StrictStr] = Field(default=None, description="Name of the crypto key to use. If the given crypto key does not exist, Vault will try to create it. This defaults to the name of the key given to Vault as the parameter if unspecified.")
    key_ring: Optional[StrictStr] = Field(default=None, description="Full Google Cloud resource ID of the key ring with the project and location (e.g. projects/my-project/locations/global/keyRings/my-keyring). If the given key ring does not exist, Vault will try to create it during a create operation.")
    labels: Optional[Dict[str, Any]] = Field(default=None, description="Arbitrary key=value label to apply to the crypto key. To specify multiple labels, specify this argument multiple times (e.g. labels=\"a=b\" labels=\"c=d\").")
    protection_level: Optional[StrictStr] = Field(default=None, description="Level of protection to use for the key management. Valid values are \"software\" and \"hsm\". The default value is \"software\". The value cannot be changed after creation.")
    purpose: Optional[StrictStr] = Field(default=None, description="Purpose of the key. Valid options are \"asymmetric_decrypt\", \"asymmetric_sign\", and \"encrypt_decrypt\". The default value is \"encrypt_decrypt\". The value cannot be changed after creation.")
    rotation_period: Optional[StrictStr] = Field(default=None, description="Amount of time between crypto key version rotations. This is specified as a time duration value like 72h (72 hours). The smallest possible value is 24h. This value only applies to keys with a purpose of \"encrypt_decrypt\".")
    __properties: ClassVar[List[str]] = ["algorithm", "crypto_key", "key_ring", "labels", "protection_level", "purpose", "rotation_period"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GoogleCloudKmsWriteKeyRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GoogleCloudKmsWriteKeyRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "algorithm": obj.get("algorithm"),
            "crypto_key": obj.get("crypto_key"),
            "key_ring": obj.get("key_ring"),
            "labels": obj.get("labels"),
            "protection_level": obj.get("protection_level"),
            "purpose": obj.get("purpose"),
            "rotation_period": obj.get("rotation_period")
        })
        return _obj


